@@ -7,6 +7,9 @@ from gsc.exercises import (
     merge_conflict,
     multiple_remotes,
     use_the_force,
+    revert,
+    reset_file,
+    amend,
 )
 
 
@@ -43,5 +46,11 @@ def setup(gsc_id: str):
         multiple_remotes.setup()
     elif gsc_id == "use_the_force":
         use_the_force.setup()
+    elif gsc_id == "revert":
+        revert.setup()
+    elif gsc_id == "reset_file":
+        reset_file.setup()
+    elif gsc_id == "amend":
+        amend.setup()
     else:
         raise SetupError("Unknown Git Scientist exercise. Try upgrading gsc.")
